import setuptools
from setuptools import find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="PsychonautCrawler",
    version="1.0.1",
    author="Ellis Barnes",
    author_email="EllisBarnes00@gmail.com",
    description="A crawler for PsychonautWiki wrote in python.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    license = open("LICENSE").read(),
    url="https://github.com/BlakeBarnes00/PsychonautCrawler",
    project_urls={
                "Bug Tracker": "https://github.com/BlakeBarnes00/PsychonautCrawler/issues",
    },
    classifiers=[
        "Development Status :: 1 - Planning",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: The Unlicense (Unlicense)",
        "Operating System :: OS Independent",
        "Intended Audience :: Science/Research"
    ],
    scripts=["bin/run.py"],
    packages=["psychonautcrawler"],
    python_requires=">=3.6",
)



from functools import reduce
import requests
from bs4 import BeautifulSoup
from requests.api import head

class Crawler:
	def __init__(self, url):
		self.page = requests.get(url)
		self.soup = BeautifulSoup(self.page.content, 'html.parser')

	def print_info(self):
		print(f"URL: {self.page.url}")

	def print_doses(self):
		doses = {}

		# find specific table
		dose_table = self.soup.select_one('table#InfoTable table.ROATable.mw-collapsible tbody')
		substance_title = self.soup.select_one('table#InfoTable tr.SubstanceTitle').text.strip()

		for row in dose_table.find_all('tr', class_="ROASectionRow", limit=6):
			header = row.th.text
			dose = row.td.text
			doses[header] = dose
			
		# Remove this, it isnt a dose.
		# doses.pop("Bioavailability")

		print(f"{substance_title:>0s}".center(50))
		for k, v in doses.items():
			print(f"{k:>0s} : {v:<0s}".center(50).format(k, v))
		
